@@ -306,7 +306,7 @@ class Column(gobject.GObject):
             treeview_column = objectlist.get_treeview_column(other_column)
 
         treeview_column.attribute = self.attribute
-        renderer, renderer_prop = self._guess_renderer_for_type(model)
+        renderer, renderer_prop = self.create_renderer(model)
         if self.on_attach_renderer:
             self.on_attach_renderer(renderer)
         justify = self.justify
@@ -347,6 +347,9 @@ class Column(gobject.GObject):
         else:
             expand = True
 
+        if self.data_type == gtk.gdk.Pixbuf:
+            renderer.set_padding(2, 0)
+
         if self.pack_end:
             treeview_column.pack_end(renderer, expand)
         else:
@@ -383,7 +386,7 @@ class Column(gobject.GObject):
 
         return treeview_column
 
-    def _guess_renderer_for_type(self, model):
+    def create_renderer(self, model):
         """Gusses which CellRenderer we should use for a given type.
         It also set the property of the renderer that depends on the model,
         in the renderer.
@@ -477,6 +480,9 @@ class Column(gobject.GObject):
         data = column.get_attribute(obj, column.attribute, None)
         text = column.as_string(data, obj)
 
+        if self._objectlist.cell_data_func:
+            text = self._objectlist.cell_data_func(self, renderer, obj, text)
+
         renderer.set_property(renderer_prop, text)
 
         if column.renderer_func:
@@ -978,6 +984,7 @@ class ObjectList(gtk.HBox):
         self._autosize = True
         self._vscrollbar = None
         self._message_label = None
+        self.cell_data_func = None
 
         gtk.HBox.__init__(self)
         # we always want a vertical scrollbar. Otherwise the button on top
@@ -1992,6 +1999,9 @@ class ObjectList(gtk.HBox):
         self._viewport.hide()
         self._message_label.set_label("")
 
+    def set_cell_data_func(self, cell_data_func):
+        self.cell_data_func = cell_data_func
+
 type_register(ObjectList)
 
 
